/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02884
 |        NATIONAL TREATMENT IMPROVEMENT EVALUATION STUDY (NTIES),
 |                               1992-1997
 |        (DATASET 0002: NTIES TREATMENT EXPERIENCE QUESTIONNAIRE
 |                                (NTEQ))
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02884-0002-statasetup.do)
 |
 **************************************************************************/

set mem 9m  /* Allocating 9 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Treatment Improvement Evaluation Study (NTIES), 1992-1997, NTIES Treatment Experience Questionnaire (NTEQ)"

#delimit ;
label define T5        -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "JAIL" 3 "PRISON" 4 "OTHER SITES" ;
label define T6        -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "MALE" 2 "FEMALE" ;
label define T8        -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ENGLISH" 2 "SPANISH" 3 "OTHER"
                       4 "DEPENDS" ;
label define T9        -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T11       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T32       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "ENGLISH" 1 "SPANISH" ;
label define T71       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "FIRST/LAST NAME MATCH INTAKE"
                       2 "FIRST/LAST NAME DO NOT MATCH INTAKE" ;
label define T83       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "DOB MATCHES INTAKE"
                       2 "DOB DOES NOT MATCH INTAKE" ;
label define T87       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "JAIL/DETENTION" 2 "OTHER" ;
label define T89       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO"
                       3 "NOT INCARCERATED AT NRIQ BUT WAS AT NTEQ" ;
label define T93       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "2-6 DAYS" 3 "1-3 WEEKS" 4 "1-3 MONTHS"
                       5 "4-12 MONTHS" 6 "MORE THAN 1 YEAR" ;
label define T99M3     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T99M4     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define PRGMTYPE  -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "CRITICAL POPULATIONS"
                       2 "CORRECTIONAL SETTINGS"
                       3 "NON-INCARCERATED OFFENDERS" 4 "TARGET CITIES"
                       5 "ADOLESCENT/JUVENILE JUSTICE" 6 "PUBLIC HOUSING" ;
label define TRT2      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "IN-PATIENT"
                       2 "LONG-TERM RESIDENTIAL/IN-PATIENT"
                       3 "OUT-PATIENT METHADONE" 4 "AMBULATORY OUT-PATIENT" ;
label define PRG2      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "AJJ/PH" 2 "CRIMINAL JUSTICE"
                       3 "TARGET CITIES" ;
label define CELL      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "CP/SR" 2 "CP/LR" 3 "CP/OP" 4 "TC/SR"
                       5 "TC/LR" 6 "TC/OP" 7 "CJ/SR" 8 "CJ/LR" 9 "CJ/OP"
                       10 "METHADONE" ;
label define CELL2     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "METHADONE"
                       2 "NON-METHADONE OUT-PATIENT"
                       3 "SHORT-TERM RESIDENTIAL" 4 "LONG-TERM RESIDENTIAL"
                       5 "CORRECTIONAL SETTINGS" ;
label define T115      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T117      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "R STILL IN TREATMENT" ;
label define T119      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NOT IN TREATMENT" ;
label define T132      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "STILL IN TREATMENT"
                       2 "STOPPED TREATMENT" ;
label define T141      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" ;
label define T145      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "0" 1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6"
                       7 "7" 8 "8" 9 "9" 10 "10" 11 "11" 12 "12" 13 "13"
                       14 "14" 15 "15" 16 "16" 17 "17" 18 "18" 19 "19"
                       20 "20" 21 "21" 22 "22" 23 "23" 24 "24" 27 "25-29"
                       32 "30-34" 37 "35-39" 42 "40-44" 47 "45-49"
                       50 "50 OR MORE" ;
label define T153      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T158      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "R HELPED DECIDE"
                       2 "SOMEONE AT PROGRAM DECIDED WITHOUT R"
                       3 "NO GOALS SET" ;
label define T164M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T164M13   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO GOALS SET" ;
label define T169      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY MUCH"
                       4 "NO GOALS SET" ;
label define T172      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY MUCH" 2 "SOMEWHAT" 3 "NOT AT ALL"
                       4 "NO GOALS SET" ;
label define T176      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "PERSON EXISTS" 2 "NO SUCH PERSON" ;
label define T183      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "5 OR MORE TIMES PER WEEK"
                       2 "2-4 TIMES PER WEEK" 3 "1 TIME PER WEEK"
                       4 "2-4 TIMES PER MONTH" 5 "ONCE A MONTH OR LESS"
                       6 "TOTAL NUMBER OF SESSIONS (SPECIFY)"
                       7 "NO SUCH PERSON" ;
label define T191      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 10 MINUTES"
                       2 "10-29 MINUTES" 3 "30-59 MINUTES" 4 "1-2 HOURS"
                       5 "MORE THAN 2 HOURS" 6 "NO SUCH PERSON" ;
label define T195      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY MUCH" 2 "SOMEWHAT" 3 "NOT AT ALL"
                       4 "NO SUCH PERSON" ;
label define T198      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY MUCH" 2 "SOMEWHAT" 3 "NOT AT ALL"
                       4 "NO SUCH PERSON" ;
label define T201      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO SUCH PERSON" ;
label define T203      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T211      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-3" 4 "4-10"
                       5 "11 OR MORE" ;
label define T213      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-3" 4 "4-10"
                       5 "11 OR MORE" ;
label define T215      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-3" 4 "4-10"
                       5 "11 OR MORE" ;
label define T217      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-3" 4 "4-10"
                       5 "11 OR MORE" ;
label define T221      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T225      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-3" 4 "4-10"
                       5 "11 OR MORE" ;
label define T229      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-3" 4 "4-10"
                       5 "11 OR MORE" ;
label define T233M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T233M13   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T241A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T241A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define T243      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE OR TWO DAYS" 3 "3-5 DAYS"
                       4 "6-7 DAYS" 5 "3-10 DAYS" 6 "11-20 DAYS"
                       7 "21 DAYS OR MORE" 8 "TOTAL OVER TREATMENT PERIOD" ;
label define T246M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M13   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T246M14   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T247      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T248      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE OR TWO DAYS" 3 "3-5 DAYS"
                       4 "6-7 DAYS" 5 "3-10 DAYS" 6 "11-20 DAYS"
                       7 "21 DAYS OR MORE" 8 "TOTAL OVER TREATMENT PERIOD" ;
label define T250      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE OF THE TIME"
                       2 "LESS THAN HALF OF THE TIME" 3 "HALF OF THE TIME"
                       4 "MORE THAN HALF OF THE TIME" 5 "EVERY TIME" ;
label define T251      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN HALF OF THE TIME"
                       2 "MORE THAN HALF OF THE TIME" ;
label define T252      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T253      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE OR TWO DAYS" 3 "3-5 DAYS"
                       4 "6-7 DAYS" 5 "3-10 DAYS" 6 "11-20 DAYS"
                       7 "21 DAYS OR MORE" 8 "TOTAL OVER TREATMENT PERIOD" ;
label define T255      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE OR TWO DAYS" 3 "3-5 DAYS"
                       4 "6-7 DAYS" 5 "3-10 DAYS" 6 "11-20 DAYS"
                       7 "21 DAYS OR MORE" 8 "TOTAL OVER TREATMENT PERIOD" ;
label define T257      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T261      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "TOO HIGH" 2 "THE RIGHT AMOUNT"
                       3 "TOO LOW" ;
label define T262M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T262M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T262M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T263      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T264M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T264M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T264M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T265      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T266M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T266M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T266M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T267      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-3" 3 "4-10" 4 "11 OR MORE" ;
label define T268      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY HELPFUL" 2 "SOMEWHAT HELPFUL"
                       3 "NOT AT ALL HELPFUL" ;
label define T269      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T270      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE OR TWO DAYS" 3 "3-5 DAYS"
                       4 "6-7 DAYS" 5 "3-10 DAYS" 6 "11-20 DAYS"
                       7 "21 DAYS OR MORE" 8 "TOTAL OVER TREATMENT PERIOD" ;
label define T272      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T273      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T274M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T274M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T274M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T277      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T278      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T279      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T280      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T281      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T282      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T284      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T285M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "NO" ;
label define T285M9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T285M10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T285M12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T285M13   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T285M16   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T285M17   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T285M18   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "NO" ;
label define T285M19   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "NO" ;
label define T285M20   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T285M21   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T285M22   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T286      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE TIME" 2 "MORE THAN ONE TIME" ;
label define T287      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "AGE 26 OR OLDER" ;
label define T289      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T291      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T295      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "5 OR MORE TIMES PER WEEK"
                       2 "2-4 TIMES PER WEEK" 3 "ONCE A WEEK"
                       4 "2-3 TIMES A MONTH" 5 "ONCE A MONTH OR LESS" ;
label define T297      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T298      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T299M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T299M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T299M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T300      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY HELPFUL" 2 "SOMEWHAT HELPFUL"
                       3 "NOT AT ALL HELPFUL" ;
label define T307      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "RS OWN APARTMENT/HOUSE"
                       2 "SOMEONE ELSES APARTMENT/HOUSE"
                       3 "HOTEL, MOTEL, ROOMING/BOARDING HOUSE/DOR"
                       4 "HOMELESS SHELTER/ON STREET"
                       5 "OTHER TYPE OF SHELTER" 6 "HOSPITAL"
                       7 "IN JAIL/PRISON/DETENTION/WORK RELEASE"
                       8 "GROUP HOME/TREATMENT CENTER" 9 "SOME OTHER PLACE" ;
label define T309      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T310      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T312      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T313      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T315      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T316      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T321      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO"
                       3 "CHILDCARE NOT NECESSARY" ;
label define T324M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T324M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T324M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T326      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO"
                       3 "CHILDCARE NOT NECESSARY" ;
label define T331      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T333M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T333M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T333M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T334      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-3" 3 "4-10" 4 "11 OR MORE" ;
label define T335      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T336M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T336M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T336M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T338      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-3" 3 "4-10" 4 "11 OR MORE" ;
label define T339      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T340M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T340M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T340M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T341      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-3" 3 "4-10" 4 "11 OR MORE" ;
label define T342      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T343M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T343M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T343M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T344      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-3" 3 "4-10" 4 "11 OR MORE" ;
label define T346      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T347M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T347M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T347M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T348      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-3" 3 "4-10" 4 "11 OR MORE" ;
label define T349      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T350M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T350M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T350M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T357      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T358M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T358M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T358M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T358M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T358M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T358M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T358M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T362M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T362M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T362M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T364      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO"
                       3 "RECEIVED DIPLOMA/GED PRIOR TO INTAKE" ;
label define T365      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "HIGH SCHOOL DIPLOMA"
                       2 "GED CERTIFICATE"
                       3 "RECEIVED DIPLOMA/GED PRIOR TO INTAKE" ;
label define T369      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VOCATIONAL/TRADE DIPLOMA"
                       2 "OTHER DIPLOMA" 3 "NO DIPLOMA" ;
label define T374      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T376M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T381      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "R HAS NEVER HAD A JOB" ;
label define T383      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1 WEEK" 2 "2 WEEKS" 3 "3 WEEKS"
                       4 "4 WEEKS" 5 "5 WEEKS" 6 "6 WEEKS" 7 "7 WEEKS"
                       8 "8 OR MORE WEEKS" ;
label define T384      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T385      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN ONE MONTH" 2 "1-6 MONTHS"
                       3 "7-12 MONTHS" 4 "MORE THAN 12 MONTHS" ;
label define T386      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1-20 HOURS" 2 "21-35 HOURS"
                       3 "36-45 HOURS" 4 "46 HOURS OR MORE" ;
label define T388      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T389M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T389M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T389M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T390      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-3" 3 "4-10" 4 "11 OR MORE" ;
label define T392      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T393M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T393M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T393M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T394      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY HELPFUL" 2 "SOMEWHAT HELPFUL"
                       3 "NOT AT ALL HELPFUL" ;
label define T398      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T401      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO"
                       3 "NOT ASKED OF INPATIENTS" ;
label define T403      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T404M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T404M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T404M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T409      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY HELPFUL" 2 "SOMEWHAT HELPFUL"
                       3 "NOT AT ALL HELPFUL" ;
label define T410      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T417      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "S-S LESS THAN 2 WEEKS" ;
label define T418      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "S-S LESS THAN 2 WEEKS"
                       4 "SKIPPED YES TO 417" ;
label define T420      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T422      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T424      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T426M10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T428M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T428M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T428M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T429      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-3" 3 "4-10" 4 "11 OR MORE" ;
label define T431      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T434M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T434M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T434M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T435      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T436      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T437M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T437M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T437M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "STILL IN TREATMENT" ;
label define T438      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1-5 TIMES" 2 "6-10 TIMES"
                       3 "11-30 TIMES" 4 "31 TIMES OR MORE"
                       5 "STILL IN TREATMENT" ;
label define T446      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "EXCELLENT" 2 "GOOD" 3 "FAIR" 4 "POOR" ;
label define T448      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T452      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T454      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T455      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1 NIGHT" 2 "2 NIGHTS" 3 "3 NIGHTS"
                       4 "4 OR MORE NIGHTS" ;
label define T457      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE DAY" 3 "2-3 DAYS"
                       4 "4-10 DAYS" 5 "11 OR MORE DAYS" ;
label define T459M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T459M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T459M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T461      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T463M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T463M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T463M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T464      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T465M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T465M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T465M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T466      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1 TIME" 2 "2 TIMES"
                       3 "3 OR MORE TIMES" 4 "UNSPECIFIED (SEE NOTE 5)" ;
label define T469      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T472      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T475M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T475M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T475M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T480      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-9" 4 "10 OR MORE" ;
label define T484      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE OF THE TIME"
                       2 "LESS THAN HALF THE TIME" 3 "HALF OF THE TIME"
                       4 "MORE THAN HALF THE TIME" 5 "EVERY TIME" ;
label define T485      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T486M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T486M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T486M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T487      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T488      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T489M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T489M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T489M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T490      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-3" 3 "4-10" 4 "11 OR MORE" ;
label define T491      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T492M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T492M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T492M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T500      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T509      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "EDUCATION" 2 "FAMILY ISSUES"
                       3 "DRUG OR ALCOHOL USE" 4 "MENTAL HEALTH"
                       5 "MEDICAL EMOTIONS, NERVES OR AND HEALTH I"
                       6 "LEGAL PROBLEMS" 7 "JOB OR EMPLOYMENT PROBLEMS"
                       8 "INCOME OR FINANCIAL PROBLEMS" 9 "HOUSING ISSUES"
                       10 "OTHER" ;
label define T513      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T516M10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T518      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T519M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T519M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T519M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define T520      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY HELPFUL" 2 "SOMEWHAT HELPFUL"
                       3 "NOT AT ALL HELPFUL" ;
label define T523      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY MUCH" 2 "SOMEWHAT" 3 "NOT AT ALL" ;
label define T547      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define T554      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define T128      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "MONTHS" 2 "R < 48 HOURS DISCHARGE"
                       3 "STOPPED TREATMENT" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace T5 = . if (T5 <= -1 )
replace T6 = . if (T6 <= -1 )
replace T8 = . if (T8 <= -1 )
replace T9 = . if (T9 <= -1 )
replace T11 = . if (T11 <= -1 )
replace T32 = . if (T32 <= -1 )
replace T71 = . if (T71 <= -1 )
replace T83 = . if (T83 <= -1 )
replace T87 = . if (T87 <= -1 )
replace T89 = . if (T89 <= -1 )
replace T93 = . if (T93 <= -1 )
replace T99M3 = . if (T99M3 <= -1 )
replace T99M4 = . if (T99M4 <= -1 )
replace PRGMTYPE = . if (PRGMTYPE <= -1 )
replace TRT2 = . if (TRT2 <= -1 )
replace PRG2 = . if (PRG2 <= -1 )
replace CELL = . if (CELL <= -1 )
replace CELL2 = . if (CELL2 <= -1 )
replace T115 = . if (T115 <= -1 )
replace T117 = . if (T117 == 3)
replace T117 = . if (T117 <= -1 )
replace T119 = . if (T119 == 3)
replace T119 = . if (T119 <= -1 )
replace T132 = . if (T132 <= -1 )
replace T141 = . if (T141 <= -1 )
replace T145 = . if (T145 <= -1 )
replace T153 = . if (T153 <= -1 )
replace T158 = . if (T158 <= -1 )
replace T164M1 = . if (T164M1 <= -1 )
replace T164M2 = . if (T164M2 <= -1 )
replace T164M3 = . if (T164M3 <= -1 )
replace T164M4 = . if (T164M4 <= -1 )
replace T164M5 = . if (T164M5 <= -1 )
replace T164M6 = . if (T164M6 <= -1 )
replace T164M7 = . if (T164M7 <= -1 )
replace T164M8 = . if (T164M8 <= -1 )
replace T164M9 = . if (T164M9 <= -1 )
replace T164M10 = . if (T164M10 <= -1 )
replace T164M11 = . if (T164M11 <= -1 )
replace T164M12 = . if (T164M12 <= -1 )
replace T164M13 = . if (T164M13 <= -1 )
replace T169 = . if (T169 <= -1 )
replace T172 = . if (T172 <= -1 )
replace T176 = . if (T176 <= -1 )
replace T183 = . if (T183 == 7)
replace T183 = . if (T183 <= -1 )
replace T191 = . if (T191 == 6)
replace T191 = . if (T191 <= -1 )
replace T195 = . if (T195 == 4)
replace T195 = . if (T195 <= -1 )
replace T198 = . if (T198 == 4)
replace T198 = . if (T198 <= -1 )
replace T201 = . if (T201 == 3)
replace T201 = . if (T201 <= -1 )
replace T203 = . if (T203 <= -1 )
replace T211 = . if (T211 <= -1 )
replace T213 = . if (T213 <= -1 )
replace T215 = . if (T215 <= -1 )
replace T217 = . if (T217 <= -1 )
replace T221 = . if (T221 <= -1 )
replace T225 = . if (T225 <= -1 )
replace T229 = . if (T229 <= -1 )
replace T233M1 = . if (T233M1 <= -1 )
replace T233M2 = . if (T233M2 <= -1 )
replace T233M3 = . if (T233M3 <= -1 )
replace T233M4 = . if (T233M4 <= -1 )
replace T233M5 = . if (T233M5 <= -1 )
replace T233M6 = . if (T233M6 <= -1 )
replace T233M7 = . if (T233M7 <= -1 )
replace T233M8 = . if (T233M8 <= -1 )
replace T233M9 = . if (T233M9 <= -1 )
replace T233M10 = . if (T233M10 <= -1 )
replace T233M11 = . if (T233M11 <= -1 )
replace T233M12 = . if (T233M12 <= -1 )
replace T233M13 = . if (T233M13 <= -1 )
replace T241A1 = . if (T241A1 <= -1 )
replace T241A2 = . if (T241A2 <= -1 )
replace T241A3 = . if (T241A3 <= -1 )
replace T241A4 = . if (T241A4 <= -1 )
replace T241A5 = . if (T241A5 <= -1 )
replace T241A6 = . if (T241A6 <= -1 )
replace T241A7 = . if (T241A7 <= -1 )
replace T241A8 = . if (T241A8 <= -1 )
replace T241A9 = . if (T241A9 <= -1 )
replace T241A10 = . if (T241A10 <= -1 )
replace T241A11 = . if (T241A11 <= -1 )
replace T241A12 = . if (T241A12 <= -1 )
replace T243 = . if (T243 <= -1 )
replace T246M1 = . if (T246M1 <= -1 )
replace T246M2 = . if (T246M2 <= -1 )
replace T246M3 = . if (T246M3 <= -1 )
replace T246M4 = . if (T246M4 <= -1 )
replace T246M5 = . if (T246M5 <= -1 )
replace T246M6 = . if (T246M6 <= -1 )
replace T246M7 = . if (T246M7 <= -1 )
replace T246M8 = . if (T246M8 <= -1 )
replace T246M9 = . if (T246M9 <= -1 )
replace T246M11 = . if (T246M11 <= -1 )
replace T246M12 = . if (T246M12 <= -1 )
replace T246M13 = . if (T246M13 <= -1 )
replace T246M14 = . if (T246M14 <= -1 )
replace T247 = . if (T247 <= -1 )
replace T248 = . if (T248 <= -1 )
replace T250 = . if (T250 <= -1 )
replace T251 = . if (T251 <= -1 )
replace T252 = . if (T252 <= -1 )
replace T253 = . if (T253 <= -1 )
replace T255 = . if (T255 <= -1 )
replace T257 = . if (T257 <= -1 )
replace T261 = . if (T261 <= -1 )
replace T262M1 = . if (T262M1 <= -1 )
replace T262M2 = . if (T262M2 <= -1 )
replace T262M3 = . if (T262M3 <= -1 )
replace T263 = . if (T263 <= -1 )
replace T264M1 = . if (T264M1 <= -1 )
replace T264M2 = . if (T264M2 <= -1 )
replace T264M3 = . if (T264M3 <= -1 )
replace T265 = . if (T265 <= -1 )
replace T266M1 = . if (T266M1 <= -1 )
replace T266M2 = . if (T266M2 <= -1 )
replace T266M3 = . if (T266M3 <= -1 )
replace T267 = . if (T267 <= -1 )
replace T268 = . if (T268 <= -1 )
replace T269 = . if (T269 <= -1 )
replace T270 = . if (T270 <= -1 )
replace T272 = . if (T272 == 3)
replace T272 = . if (T272 <= -1 )
replace T273 = . if (T273 == 3)
replace T273 = . if (T273 <= -1 )
replace T274M1 = . if (T274M1 == 3)
replace T274M1 = . if (T274M1 <= -1 )
replace T274M2 = . if (T274M2 == 3)
replace T274M2 = . if (T274M2 <= -1 )
replace T274M3 = . if (T274M3 == 3)
replace T274M3 = . if (T274M3 <= -1 )
replace T277 = . if (T277 <= -1 )
replace T278 = . if (T278 <= -1 )
replace T279 = . if (T279 <= -1 )
replace T280 = . if (T280 <= -1 )
replace T281 = . if (T281 <= -1 )
replace T282 = . if (T282 <= -1 )
replace T284 = . if (T284 <= -1 )
replace T285M7 = . if (T285M7 <= -1 )
replace T285M9 = . if (T285M9 <= -1 )
replace T285M10 = . if (T285M10 <= -1 )
replace T285M12 = . if (T285M12 <= -1 )
replace T285M13 = . if (T285M13 <= -1 )
replace T285M16 = . if (T285M16 <= -1 )
replace T285M17 = . if (T285M17 <= -1 )
replace T285M18 = . if (T285M18 <= -1 )
replace T285M19 = . if (T285M19 <= -1 )
replace T285M20 = . if (T285M20 <= -1 )
replace T285M21 = . if (T285M21 <= -1 )
replace T285M22 = . if (T285M22 <= -1 )
replace T286 = . if (T286 <= -1 )
replace T287 = . if (T287 == 3)
replace T287 = . if (T287 <= -1 )
replace T289 = . if (T289 <= -1 )
replace T291 = . if (T291 <= -1 )
replace T295 = . if (T295 <= -1 )
replace T297 = . if (T297 <= -1 )
replace T298 = . if (T298 <= -1 )
replace T299M1 = . if (T299M1 <= -1 )
replace T299M2 = . if (T299M2 <= -1 )
replace T299M3 = . if (T299M3 <= -1 )
replace T300 = . if (T300 <= -1 )
replace T307 = . if (T307 <= -1 )
replace T309 = . if (T309 <= -1 )
replace T310 = . if (T310 <= -1 )
replace T312 = . if (T312 <= -1 )
replace T313 = . if (T313 <= -1 )
replace T315 = . if (T315 <= -1 )
replace T316 = . if (T316 <= -1 )
replace T321 = . if (T321 <= -1 )
replace T324M1 = . if (T324M1 <= -1 )
replace T324M2 = . if (T324M2 <= -1 )
replace T324M3 = . if (T324M3 <= -1 )
replace T326 = . if (T326 <= -1 )
replace T331 = . if (T331 <= -1 )
replace T333M1 = . if (T333M1 <= -1 )
replace T333M2 = . if (T333M2 <= -1 )
replace T333M3 = . if (T333M3 <= -1 )
replace T334 = . if (T334 <= -1 )
replace T335 = . if (T335 <= -1 )
replace T336M1 = . if (T336M1 <= -1 )
replace T336M2 = . if (T336M2 <= -1 )
replace T336M3 = . if (T336M3 <= -1 )
replace T338 = . if (T338 <= -1 )
replace T339 = . if (T339 <= -1 )
replace T340M1 = . if (T340M1 <= -1 )
replace T340M2 = . if (T340M2 <= -1 )
replace T340M3 = . if (T340M3 <= -1 )
replace T341 = . if (T341 <= -1 )
replace T342 = . if (T342 <= -1 )
replace T343M1 = . if (T343M1 <= -1 )
replace T343M2 = . if (T343M2 <= -1 )
replace T343M3 = . if (T343M3 <= -1 )
replace T344 = . if (T344 <= -1 )
replace T346 = . if (T346 <= -1 )
replace T347M1 = . if (T347M1 <= -1 )
replace T347M2 = . if (T347M2 <= -1 )
replace T347M3 = . if (T347M3 <= -1 )
replace T348 = . if (T348 <= -1 )
replace T349 = . if (T349 <= -1 )
replace T350M1 = . if (T350M1 <= -1 )
replace T350M2 = . if (T350M2 <= -1 )
replace T350M3 = . if (T350M3 <= -1 )
replace T357 = . if (T357 <= -1 )
replace T358M1 = . if (T358M1 <= -1 )
replace T358M2 = . if (T358M2 <= -1 )
replace T358M3 = . if (T358M3 <= -1 )
replace T358M4 = . if (T358M4 <= -1 )
replace T358M5 = . if (T358M5 <= -1 )
replace T358M6 = . if (T358M6 <= -1 )
replace T358M7 = . if (T358M7 <= -1 )
replace T362M1 = . if (T362M1 <= -1 )
replace T362M2 = . if (T362M2 <= -1 )
replace T362M3 = . if (T362M3 <= -1 )
replace T364 = . if (T364 <= -1 )
replace T365 = . if (T365 <= -1 )
replace T369 = . if (T369 <= -1 )
replace T374 = . if (T374 <= -1 )
replace T376M1 = . if (T376M1 <= -1 )
replace T381 = . if (T381 <= -1 )
replace T383 = . if (T383 <= -1 )
replace T384 = . if (T384 <= -1 )
replace T385 = . if (T385 <= -1 )
replace T386 = . if (T386 <= -1 )
replace T388 = . if (T388 <= -1 )
replace T389M1 = . if (T389M1 <= -1 )
replace T389M2 = . if (T389M2 <= -1 )
replace T389M3 = . if (T389M3 <= -1 )
replace T390 = . if (T390 <= -1 )
replace T392 = . if (T392 <= -1 )
replace T393M1 = . if (T393M1 <= -1 )
replace T393M2 = . if (T393M2 <= -1 )
replace T393M3 = . if (T393M3 <= -1 )
replace T394 = . if (T394 <= -1 )
replace T398 = . if (T398 <= -1 )
replace T401 = . if (T401 == 3)
replace T401 = . if (T401 <= -1 )
replace T403 = . if (T403 <= -1 )
replace T404M1 = . if (T404M1 <= -1 )
replace T404M2 = . if (T404M2 <= -1 )
replace T404M3 = . if (T404M3 <= -1 )
replace T409 = . if (T409 <= -1 )
replace T410 = . if (T410 <= -1 )
replace T417 = . if (T417 == 3)
replace T417 = . if (T417 <= -1 )
replace T418 = . if (T418 == 3)
replace T418 = . if (T418 <= -1 )
replace T420 = . if (T420 <= -1 )
replace T422 = . if (T422 <= -1 )
replace T424 = . if (T424 <= -1 )
replace T426M1 = . if (T426M1 <= -1 )
replace T426M2 = . if (T426M2 <= -1 )
replace T426M3 = . if (T426M3 <= -1 )
replace T426M4 = . if (T426M4 <= -1 )
replace T426M5 = . if (T426M5 <= -1 )
replace T426M6 = . if (T426M6 <= -1 )
replace T426M7 = . if (T426M7 <= -1 )
replace T426M8 = . if (T426M8 <= -1 )
replace T426M9 = . if (T426M9 <= -1 )
replace T426M10 = . if (T426M10 <= -1 )
replace T428M1 = . if (T428M1 <= -1 )
replace T428M2 = . if (T428M2 <= -1 )
replace T428M3 = . if (T428M3 <= -1 )
replace T429 = . if (T429 <= -1 )
replace T431 = . if (T431 <= -1 )
replace T434M1 = . if (T434M1 <= -1 )
replace T434M2 = . if (T434M2 <= -1 )
replace T434M3 = . if (T434M3 <= -1 )
replace T435 = . if (T435 == 3)
replace T435 = . if (T435 <= -1 )
replace T436 = . if (T436 == 3)
replace T436 = . if (T436 <= -1 )
replace T437M1 = . if (T437M1 == 3)
replace T437M1 = . if (T437M1 <= -1 )
replace T437M2 = . if (T437M2 == 3)
replace T437M2 = . if (T437M2 <= -1 )
replace T437M3 = . if (T437M3 == 3)
replace T437M3 = . if (T437M3 <= -1 )
replace T438 = . if (T438 == 5)
replace T438 = . if (T438 <= -1 )
replace T446 = . if (T446 <= -1 )
replace T448 = . if (T448 <= -1 )
replace T452 = . if (T452 <= -1 )
replace T454 = . if (T454 <= -1 )
replace T455 = . if (T455 <= -1 )
replace T457 = . if (T457 <= -1 )
replace T459M1 = . if (T459M1 <= -1 )
replace T459M2 = . if (T459M2 <= -1 )
replace T459M3 = . if (T459M3 <= -1 )
replace T461 = . if (T461 <= -1 )
replace T463M1 = . if (T463M1 <= -1 )
replace T463M2 = . if (T463M2 <= -1 )
replace T463M3 = . if (T463M3 <= -1 )
replace T464 = . if (T464 <= -1 )
replace T465M1 = . if (T465M1 <= -1 )
replace T465M2 = . if (T465M2 <= -1 )
replace T465M3 = . if (T465M3 <= -1 )
replace T466 = . if (T466 <= -1 )
replace T469 = . if (T469 <= -1 )
replace T472 = . if (T472 <= -1 )
replace T475M1 = . if (T475M1 <= -1 )
replace T475M2 = . if (T475M2 <= -1 )
replace T475M3 = . if (T475M3 <= -1 )
replace T480 = . if (T480 <= -1 )
replace T484 = . if (T484 <= -1 )
replace T485 = . if (T485 <= -1 )
replace T486M1 = . if (T486M1 <= -1 )
replace T486M2 = . if (T486M2 <= -1 )
replace T486M3 = . if (T486M3 <= -1 )
replace T487 = . if (T487 <= -1 )
replace T488 = . if (T488 <= -1 )
replace T489M1 = . if (T489M1 <= -1 )
replace T489M2 = . if (T489M2 <= -1 )
replace T489M3 = . if (T489M3 <= -1 )
replace T490 = . if (T490 <= -1 )
replace T491 = . if (T491 <= -1 )
replace T492M1 = . if (T492M1 <= -1 )
replace T492M2 = . if (T492M2 <= -1 )
replace T492M3 = . if (T492M3 <= -1 )
replace T500 = . if (T500 <= -1 )
replace T509 = . if (T509 <= -1 )
replace T513 = . if (T513 <= -1 )
replace T516M1 = . if (T516M1 <= -1 )
replace T516M2 = . if (T516M2 <= -1 )
replace T516M3 = . if (T516M3 <= -1 )
replace T516M4 = . if (T516M4 <= -1 )
replace T516M5 = . if (T516M5 <= -1 )
replace T516M6 = . if (T516M6 <= -1 )
replace T516M7 = . if (T516M7 <= -1 )
replace T516M8 = . if (T516M8 <= -1 )
replace T516M9 = . if (T516M9 <= -1 )
replace T516M10 = . if (T516M10 <= -1 )
replace T518 = . if (T518 <= -1 )
replace T519M1 = . if (T519M1 <= -1 )
replace T519M2 = . if (T519M2 <= -1 )
replace T519M3 = . if (T519M3 <= -1 )
replace T520 = . if (T520 <= -1 )
replace T523 = . if (T523 <= -1 )
replace T547 = . if (T547 <= -1 )
replace T554 = . if (T554 <= -1 )
replace T128 = . if (T128 <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

